ColReorder examples - ColReorder examples

# ColReorder example ColReorder examples

ColReorder adds the ability for the end user to click and drag column headers to reorder a table as they see fit, to DataTables. Key features include:

- Very easy integration with DataTables
- Tight integration with all other DataTables plug-ins
- The ability to exclude the first (or more) column from being movable
- Predefine a column order
- Save staving integration with DataTables